"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildInfo = void 0;
const clientVersion = require('../package.json').version;
/** @internal */
class BuildInfo {
    static calculateServerVersionFromString(versionString) {
        if (versionString == null) {
            return BuildInfo.UNKNOWN_VERSION_ID;
        }
        const info = BuildInfo.PATTERN.exec(versionString);
        if (info == null) {
            return -1;
        }
        const major = Number.parseInt(info[1]);
        const minor = Number.parseInt(info[2]);
        let patch;
        if (info[3] == null) {
            patch = 0;
        }
        else {
            patch = Number.parseInt(info[3]);
        }
        return this.calculateServerVersion(major, minor, patch);
    }
    static calculateServerVersion(major, minor, patch) {
        return BuildInfo.MAJOR_VERSION_MULTIPLIER * major + BuildInfo.MINOR_VERSION_MULTIPLIER * minor + patch;
    }
    static getClientVersion() {
        return clientVersion;
    }
    static calculateMemberVersion(m) {
        return BuildInfo.calculateServerVersion(m.major, m.minor, m.patch);
    }
}
exports.BuildInfo = BuildInfo;
BuildInfo.UNKNOWN_VERSION_ID = -1;
BuildInfo.MAJOR_VERSION_MULTIPLIER = 10000;
BuildInfo.MINOR_VERSION_MULTIPLIER = 100;
BuildInfo.PATTERN = /^([\d]+)\.([\d]+)(?:\.([\d]+))?(-[\w]+)?(-SNAPSHOT)?(-BETA-.)?$/;
//# sourceMappingURL=BuildInfo.js.map