/**
 * Lifecycle states.
 */
export declare enum LifecycleState {
    /**
     * Fired when the client is starting.
     */
    STARTING = "STARTING",
    /**
     * Fired when the client's start is completed.
     */
    STARTED = "STARTED",
    /**
     * Fired when the client is shutting down.
     */
    SHUTTING_DOWN = "SHUTTING_DOWN",
    /**
     * Fired when the client's shut down is completed.
     */
    SHUTDOWN = "SHUTDOWN",
    /**
     * Fired when the client is connected to the member.
     */
    CONNECTED = "CONNECTED",
    /**
     * Fired when the client is disconnected from the cluster.
     */
    DISCONNECTED = "DISCONNECTED",
    /**
     * Fired when the client is connected to a new cluster.
     */
    CHANGED_CLUSTER = "CHANGED_CLUSTER"
}
/**
 * Lifecycle service for Hazelcast clients. Allows to determine lifecycle
 * state of the client and shut it down.
 */
export interface LifecycleService {
    /**
     * Returns the active state of the client.
     * @returns {boolean}
     */
    isRunning(): boolean;
}
